@@ -1,21 +1,29 @@
 package App::Metabase::Relayd::Plugin;
+$App::Metabase::Relayd::Plugin::VERSION = '0.40';
+#ABSTRACT: metabase-relayd plugins
 
 use strict;
 use warnings;
 
-our $VERSION = '0.38';
-
 qq[Smokin' plugins];
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 App::Metabase::Relayd::Plugin - metabase-relayd plugins
 
+=head1 VERSION
+
+version 0.40
+
 =head1 DESCRIPTION
 
-This document describes the App::Metabase::Relayd::Plugin system for 
+This document describes the App::Metabase::Relayd::Plugin system for
 L<App::Metabase::Relayd> and L<metabase-relayd>.
 
 Plugins are a mechanism for providing additional functionality to
@@ -26,7 +34,7 @@ L<POE::Session>.
 
 =head1 INITIALISATION
 
-The plugin constructor is C<init>. L<App::Metabase::Relayd> uses 
+The plugin constructor is C<init>. L<App::Metabase::Relayd> uses
 L<Module::Pluggable> to find plugins beneath the App::Metabase::Relayd::Plugin
 namespace and will attempt to call C<init> on each plugin class that it finds.
 
@@ -64,18 +72,19 @@ C<ARG1> will be the IP address of the client that sent the report.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<App::Metabase::Relayd>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
